# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class InstagramWeb:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 根据用户名获取用户数据 | Get user data by username
    async def fetch_user_info_by_username(self, username: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_info_by_username"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}")
        return data

    # 根据用户ID获取用户数据 | Get user data by user ID
    async def fetch_user_info_by_user_id(self, user_id: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_info_by_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}")
        return data

    # 根据用户名获取用户数据V2 | Get user data by username V2
    async def fetch_user_info_by_user_id_v2(self, username: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_info_by_user_id_v2"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={username}")
        return data

    # 根据用户ID获取用户数据V2 | Get user data by user ID V2
    async def fetch_user_info_by_id_v2(self, user_id: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_info_by_user_id_v2"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}")
        return data

    # 根据用户ID获取用户数据关于信息 | Get user data about by user ID
    async def fetch_user_about_info_by_user_id(self, user_id: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_about_info_by_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}")
        return data

    # 根据用户名获取用户网页接口的个人信息 | Get user info by username web API
    async def fetch_user_info_by_username_web(self, username: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_info_by_username_web"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}")
        return data

    # 根据用户名获取用户的粉丝数据 | Get user followers by username
    async def fetch_user_followers_by_username(self, username: str, pagination_token: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_user_followers_by_username"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}&pagination_token={pagination_token}")
        return data

    # 根据用户名获取用户的正在关注的用户数据 | Get user followings by username
    async def fetch_user_following_by_username(self, username: str, pagination_token: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_user_following_by_username"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}&pagination_token={pagination_token}")
        return data

    # 根据用户ID获取用户发布的帖子 | Get user posts by user ID
    async def fetch_user_posts_by_user_id(self, user_id: str, count: int = 12, end_cursor: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_user_posts_by_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}&count={count}&end_cursor={end_cursor}")
        return data

    # 根据用户ID获取用户发布的快拍 | Get user reels by user ID
    async def fetch_user_reels_by_user_id(self, user_id: str, count: int = 12, max_id: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_user_reels_by_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}&count={count}&max_id={max_id}")
        return data

    # 根据用户ID获取用户被标记的帖子 | Get user tagged posts by user ID
    async def fetch_user_tagged_posts_by_user_id(self, user_id: str, count: int = 12, end_cursor: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_user_tagged_posts_by_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}&count={count}&end_cursor={end_cursor}")
        return data

    # 根据用户ID获取与用户相关的其他用户 | Get user related users by user ID
    async def fetch_related_users_by_user_id(self, user_id: str):
        endpoint = "/api/v1/instagram/web_app/fetch_related_users_by_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}")
        return data

    # 根据用户名获取相似的账户数据 | Get similar accounts by username
    async def fetch_similar_accounts_by_username(self, username: str):
        endpoint = "/api/v1/instagram/web_app/fetch_similar_accounts_by_username"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}")
        return data

    # 根据关键词搜索用户 | Search users by query
    async def fetch_search_users_by_keyword(self, keyword: str):
        endpoint = "/api/v1/instagram/web_app/fetch_search_users_by_keyword"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}")
        return data

    # 根据URL获取帖子数据 | Get post data by URL
    async def fetch_post_info_by_url(self, url: str):
        endpoint = "/api/v1/instagram/web_app/fetch_post_info_by_url"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 根据帖子ID获取帖子数据 | Get post data by post ID
    async def fetch_post_info_by_post_id(self, post_id: str):
        endpoint = "/api/v1/instagram/web_app/fetch_post_info_by_post_id"
        data = await self.client.fetch_get_json(f"{endpoint}?post_id={post_id}")
        return data

    # 根据帖子URL获取媒体数据 | Get media data by URL
    async def fetch_post_media_by_url(self, url: str):
        endpoint = "/api/v1/instagram/web_app/fetch_post_media_by_url"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 根据音乐ID获取音乐数据 | Get music data by music ID
    async def fetch_music_info_by_music_id(self, music_id: str):
        endpoint = "/api/v1/instagram/web_app/fetch_music_info_by_music_id"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}")
        return data

    # 根据关键词搜索话题数据 | Search hashtags by query
    async def fetch_search_hashtags_by_keyword(self, keyword: str):
        endpoint = "/api/v1/instagram/web_app/fetch_search_hashtags_by_keyword"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}")
        return data

    # 根据关键词获取话题帖子 | Get hashtag posts by query
    async def fetch_hashtag_posts_by_keyword(self, keyword: str, end_cursor: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_hashtag_posts_by_keyword"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&end_cursor={end_cursor}")
        return data

    # 根据关键词搜索地点数据 | Search locations by query
    async def fetch_search_locations_by_keyword(self, keyword: str):
        endpoint = "/api/v1/instagram/web_app/fetch_search_locations_by_keyword"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}")
        return data

    # 根据地点ID获取地点相关的帖子 | Get location posts by location ID
    async def fetch_location_posts_by_location_id(self, location_id: str, max_id: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_location_posts_by_location_id"
        data = await self.client.fetch_get_json(f"{endpoint}?location_id={location_id}&max_id={max_id}")
        return data

    # 综合搜索 | Search all by query
    async def fetch_global_search(self, keyword: str):
        endpoint = "/api/v1/instagram/web_app/fetch_global_search"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}")
        return data

    # 根据用户名获取用户的Reels数据V2 | Get user reels by username V2
    async def fetch_user_reels_by_username_v2(self, username: str, pagination_token: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_user_reels_by_username_v2"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}&pagination_token={pagination_token}")
        return data

    # 根据用户名获取用户的Stories数据 | Get user stories by username
    async def fetch_user_stories_by_username(self, username: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_stories_by_username"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}")
        return data

    # 根据用户名获取用户的highlights数据 | Get user highlights by username
    async def fetch_user_highlights_by_username(self, username: str):
        endpoint = "/api/v1/instagram/web_app/fetch_user_highlights_by_username"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}")
        return data

    # 根据highlights ID获取highlights数据 | Get highlights data by highlights ID
    async def fetch_highlights_by_highlights_id(self, highlight_id: str):
        endpoint = "/api/v1/instagram/web_app/fetch_highlights_by_highlight_id"
        data = await self.client.fetch_get_json(f"{endpoint}?highlight_id={highlight_id}")
        return data

    # 根据用户名获取用户的tv_posts数据 | Get user tv_posts by username
    async def fetch_user_tv_posts_by_username(self, username: str, pagination_token: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_user_tv_posts_by_username"
        data = await self.client.fetch_get_json(f"{endpoint}?username={username}&pagination_token={pagination_token}")
        return data

    # 根据URL获取帖子评论数据 | Get post comments by URL
    async def fetch_post_comments_by_url(self, url: str, pagination_token: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_post_comments_by_url"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}&pagination_token={pagination_token}")
        return data

    # 根据评论ID获取评论回复数据 | Get comment replies by comment ID
    async def fetch_comment_replies_by_comment_id(self, url: str, comment_id: str, pagination_token: str = None):
        endpoint = "/api/v1/instagram/web_app/fetch_comment_replies_by_comment_id"
        data = await self.client.fetch_get_json(
            f"{endpoint}?url={url}&comment_id={comment_id}&pagination_token={pagination_token}")
        return data

    # 根据URL获取帖子点赞数据 | Get post likes by URL
    async def fetch_post_likes_by_url(self, url: str):
        endpoint = "/api/v1/instagram/web_app/fetch_post_likes_by_url"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer l7sVQFh64V8ltC8fzEaNtWE60zVSopDLlpVX62fArT1FznsPds9+2RGoXw=="})

        instagram_web = InstagramWeb(client)

        # 获取用户信息 | Fetch user info
        data = await instagram_web.fetch_user_info_by_username("instagram")
        print(data)


    asyncio.run(main())



# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class NetEaseCloudMusicAppV1:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取单一歌曲信息V1（信息更全）| Fetch one music information V1 (more information)
    async def fetch_one_music_v1(self, music_id: str):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_one_music_v1"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}")
        return data

    # 获取单一歌曲信息V2（信息更少）| Fetch one music information V2 (less information)
    async def fetch_one_music_v2(self, music_id: str):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_one_music_v2"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}")
        return data

    # 获取单一歌曲歌词/Fetch one music lyric
    async def fetch_one_music_lyric(self, music_id: str):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_one_music_lyric"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}")
        return data

    # 获取单一歌曲播放地址V1（只能返回MP3格式，支持参数较少）/Fetch one music URL V1 (only MP3 format is supported, with fewer parameters)
    async def fetch_one_music_url_v1(self, music_id: str, br: str = "192000"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_one_music_url_v1"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}&br={br}")
        return data

    # 获取单一歌曲播放地址V2（支持更多参数）/Fetch one music URL V2 (support more parameters)
    async def fetch_one_music_url_v2(self, music_id: str, level: str = "exhigh", encodeType: str = "mp3"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_one_music_url_v2"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}&level={level}&encodeType={encodeType}")
        return data

    # Mlog（音乐视频）播放地址/Mlog (music video) playback address
    async def fetch_music_log_video_url(self, mlogId: str, resolution: str = "1080"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_music_log_video_url"
        data = await self.client.fetch_get_json(f"{endpoint}?mlogId={mlogId}&resolution={resolution}")
        return data

    # 获取歌曲评论/Fetch music comment
    async def fetch_music_comment(self, resource_id: str, beforeTime: str = "0", limit: str = "30"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_music_comment"
        data = await self.client.fetch_get_json(
            f"{endpoint}?resource_id={resource_id}&beforeTime={beforeTime}&limit={limit}")
        return data

    # 搜索接口V1/Search interface V1
    async def search_v1(self, keywords: str, offset: str = "0", limit: str = "20", _type: str = "1"):
        endpoint = "/api/v1/net_ease_cloud_music/app/search_v1"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keywords={keywords}&offset={offset}&limit={limit}&type={_type}")
        return data

    # 获取用户歌单/Get user playlist
    async def fetch_user_playlist(self, uid: str, offset: str = "0", limit: str = "20"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_user_playlist"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}&offset={offset}&limit={limit}")
        return data

    # 获取用户信息/Get user information
    async def fetch_user_info(self, uid: str):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_user_info"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}")
        return data

    # 获取用户动态/Fetch user event
    async def fetch_user_event(self, uid: str, _time: str = "-1", limit: str = "10"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_user_event"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}&time={_time}&limit={limit}")
        return data

    # 获取用户粉丝列表/Fetch user followers
    async def fetch_user_followers(self, uid: str, lasttime: str = "0", pagesize: str = "20"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_user_followers"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}&lasttime={lasttime}&pagesize={pagesize}")
        return data

    # 获取用户关注列表/Fetch user follows
    async def fetch_user_follows(self, uid: str, offset: str = "0", limit: str = "20"):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_user_follows"
        data = await self.client.fetch_get_json(f"{endpoint}?uid={uid}&offset={offset}&limit={limit}")
        return data

    # 获取歌手信息/Fetch artist detail
    async def fetch_artist_detail(self, artist_id: str):
        endpoint = "/api/v1/net_ease_cloud_music/app/fetch_artist_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?artist_id={artist_id}")
        return data

    # 解密POST请求中的16进制payload/Decrypt the 16-bit payload in the POST request
    async def decrypt_post_payload(self, payload: str):
        endpoint = "/api/v1/net_ease_cloud_music/app/decrypt_post_payload"
        data = await self.client.fetch_post_json(endpoint, data=payload)
        return data

    # 加密POST请求中的payload并且返回16进制/Encrypt the payload in the POST request and return 16 hexadecimal
    async def encrypt_post_payload(self, uri: str, payload: dict, add_variable: bool = False):
        endpoint = "/api/v1/net_ease_cloud_music/app/encrypt_post_payload"
        endpoint = f"{endpoint}?uri={uri}&add_variable={add_variable}"
        data = await self.client.fetch_post_json(endpoint, data=json.dumps(payload))
        return data
